==> ejc-procurement-impl-3.0.0-20251215.040143-115-sources.jar: com/ejianc/business/procurement/perform/bean/FileAnswerEntity.java <==
package com.ejianc.business.procurement.perform.bean;

import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;

/**
 * 应答文件审批档案
 * 
 * @author generator
 * 
 */
 @TableName("ejc_procurement_answer_file")
public class FileAnswerEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;
    
    @TableField(value="score")
    private String score; // 分值
    @TableField(value="enabled")
    private Integer enabled; // 启停用
    @TableField(value="content")
    private String content; // 评价项目
    @TableField(value="sec_code")
    private String secCode; // 序号
    @TableField(value="remark")
    private String remark; // 备注
    
    
    

    public String getScore() {
        return score;
    }

    public void setScore(String score) {
        this.score = score;
    }
    public Integer getEnabled() {
        return enabled;
    }

    public void setEnabled(Integer enabled) {
        this.enabled = enabled;
    }
    public String getContent() {
        return content;
    }

    public void setContent(String content) {
        this.content = content;
    }
    public String getSecCode() {
        return secCode;
    }

    public void setSecCode(String secCode) {
        this.secCode = secCode;
    }
    public String getRemark() {
        return remark;
    }

    public void setRemark(String remark) {
        this.remark = remark;
    }
    
}

==> ejc-procurement-impl-3.0.0-20251215.045513-116-sources.jar: com/ejianc/business/procurement/perform/bean/FileAnswerEntity.java <==
package com.ejianc.business.procurement.perform.bean;

import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;

/**
 * 应答文件审批档案
 * 
 * @author generator
 * 
 */
 @TableName("ejc_procurement_answer_file")
public class FileAnswerEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;
    
    @TableField(value="score")
    private String score; // 分值
    @TableField(value="enabled")
    private Integer enabled; // 启停用
    @TableField(value="content")
    private String content; // 评价项目
    @TableField(value="sec_code")
    private String secCode; // 序号
    @TableField(value="remark")
    private String remark; // 备注
    @TableField(value="pid")
    private Long pid;// 父级id

    public Long getPid() {
        return pid;
    }

    public void setPid(Long pid) {
        this.pid = pid;
    }

    public String getScore() {
        return score;
    }

    public void setScore(String score) {
        this.score = score;
    }
    public Integer getEnabled() {
        return enabled;
    }

    public void setEnabled(Integer enabled) {
        this.enabled = enabled;
    }
    public String getContent() {
        return content;
    }

    public void setContent(String content) {
        this.content = content;
    }
    public String getSecCode() {
        return secCode;
    }

    public void setSecCode(String secCode) {
        this.secCode = secCode;
    }
    public String getRemark() {
        return remark;
    }

    public void setRemark(String remark) {
        this.remark = remark;
    }
    
}
